.. image:: https://img.shields.io/pypi/v/samplify-python.svg?style=flat
   :target: https://pypi.python.org/pypi/samplify-python


Getting Started
---------------
Run ``pip install samplify-python`` to install the latest stable version from `PyPI
<https://pypi.python.org/pypi/samplify-python>`_.
